summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php')
-rw-r--r--vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php b/vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php
index a6498b882c..46ca6796d8 100644
--- a/vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php
+++ b/vendor/symfony/http-foundation/Session/Storage/Handler/RedisSessionHandler.php
@@ -34,8 +34,8 @@ class RedisSessionHandler extends AbstractSessionHandler
* List of available options:
* * prefix: The prefix to use for the keys in order to avoid collision on the Redis server.
*
* @param \Redis|\RedisArray|\RedisCluster|\Predis\Client|RedisProxy $redis
* @param array $options An associative array of options
*
* @throws \InvalidArgumentException When unsupported client or options are passed
*/
@@ -45,11 +45,11 @@ class RedisSessionHandler extends AbstractSessionHandler
!$redis instanceof \Redis &&
!$redis instanceof \RedisArray &&
!$redis instanceof \RedisCluster &&
- !$redis instanceof \Predis\Client &&
+ !$redis instanceof \Predis\ClientInterface &&
!$redis instanceof RedisProxy &&
!$redis instanceof RedisClusterProxy
) {
- throw new \InvalidArgumentException(sprintf('%s() expects parameter 1 to be Redis, RedisArray, RedisCluster or Predis\Client, %s given', __METHOD__, \is_object($redis) ? \get_class($redis) : \gettype($redis)));
+ throw new \InvalidArgumentException(sprintf('%s() expects parameter 1 to be Redis, RedisArray, RedisCluster or Predis\ClientInterface, %s given', __METHOD__, \is_object($redis) ? \get_class($redis) : \gettype($redis)));
}
if ($diff = array_diff(array_keys($options), ['prefix'])) {
@@ -34,8 +34,8 @@ class RedisSessionHandler extends AbstractSessionHandler
* * prefix: The prefix to use for the keys in order to avoid collision on the Redis server.
*
- * @param \Redis|\RedisArray|\RedisCluster|\Predis\Client|RedisProxy $redis
- * @param array $options An associative array of options
+ * @param \Redis|\RedisArray|\RedisCluster|\Predis\ClientInterface|RedisProxy $redis
+ * @param array $options An associative array of options
*
* @throws \InvalidArgumentException When unsupported client or options are passed